##  Synchronization Filters
Synchronization filters enable you to refine fact sheet mappings by limiting the number of records synchronized. The configuration of filters depends on which system is designated as the source of truth:
  * If SAP LeanIX is the source of truth, add the necessary filters in SAP LeanIX.
  * If ServiceNow is the source of truth, add the necessary filters in ServiceNow, then select these filters in SAP LeanIX. In this scenario, filters are referred to as constraints.


Additionally, you can configure graph rule constraints to determine whether a record should be synchronized based on a connection identified in ServiceNow.
![Configuring Synchronization Constraints](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274a6c437a44101498d2e54b70393315_LowRes.png)
Configuring Synchronization Constraints
